@@ -1,4 +1,3 @@
-from __future__ import print_function
 import yaml
 import requests
 import os
@@ -11,6 +10,8 @@ class PluginManager(object):
 
     def load(self):
         """
+        TODO: DEPRECATED:
+
         loads the plugins form the plugin.yml file in github
 
         :return:
@@ -23,14 +24,30 @@ class PluginManager(object):
             entry['description'] = entry['description'].strip()
 
     def uninstall(self, name):
+        """
+        pip uninstalls the package with the specified name
+        :param name: The package name
+        :return:
+        """
         plugin = "cloudmesh." + name
         print("Uninstalling:", )
         os.system("pip uninstall {name}".format(name=plugin))
 
     def pip_install(self, name):
+        """
+        pip installs the package with the specified name
+        :param name: The package name
+        :return:
+        """
         plugin = "cloudmesh." + name
         print("Installing:", )
         os.system("pip install {name}".format(name=plugin))
 
     def source_install(self, name):
+        """
+        TODO: DEPRECATED
+
+        :param name:
+        :return:
+        """
         pass
